@@ -152,10 +152,10 @@ sub sim    # This function launch the simulations in ESP-r
   my @container;
   
   my $countinstance = 0;
-  my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
+  #my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   foreach my $instance (@instances)
   {
-    my $pid = $pm->start and next; # Begins the child process
+    #my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -561,7 +561,7 @@ $printthis
       }
       $counttool++;
     }  
-    $pm->finish; # Terminates the child process
+    #$pm->finish; # Terminates the child process
     $countinstance++;
   }
   close SIMLIST;
